diff --git a/mkarchroot b/mkarchroot
index 208b144..fe2c3ef 100755
--- a/mkarchroot
+++ b/mkarchroot
 -17,29 +17,32 @@ working_dir=''
 APPNAME=$(basename "${0}")
 
 # usage: usage <exitvalue>
-usage() {
+usage ()
+{
 	echo "usage ${APPNAME} [options] working-dir [package-list | app]"
 	echo ' options:'
 	echo '    -r <app>      Run "app" within the context of the chroot'
 	echo '    -u            Update the chroot via pacman'
 	echo '    -f            Force overwrite of files in the working-dir'
+	echo '    -s            Set arch=i686 (x86_64 systems only)'
 	echo '    -C <file>     Location of a pacman config file'
 	echo '    -M <file>     Location of a makepkg config file'
 	echo '    -n            Do not copy config files into the chroot'
-	echo "    -c <dir>      Set pacman cache. Default: /var/cache/pacman/pkg"
+	echo '    -c <dir>      Set pacman cache. Default: /var/cache/pacman/pkg'
 	echo '    -h            This message'
 	exit $1
 }
 
-while getopts 'r:ufnhC:M:c:' arg; do
+while getopts 'r:ufnhsC:M:c:' arg; do
 	case "${arg}" in
 		r) RUN="$OPTARG" ;;
 		u) RUN='pacman -Syu' ;;
 		f) FORCE='y' ;;
+		s) SARCH='y' ;;
 		C) pac_conf="$OPTARG" ;;
 		M) makepkg_conf="$OPTARG" ;;
 		n) NOCOPY='y' ;;
-		c) cache_dir="$OPTARG" ;;
+		c) cache_dir="$OPTARG" ;;   
 		h|?) usage 0 ;;
 		*) echo "invalid argument '${arg}'"; usage 1 ;;
 	esac
 -74,7 +77,7 @@ fi
 
 # {{{ functions 
 
-chroot_mount() {
+chroot_mount () {
 	[ -e "${working_dir}/sys" ] || mkdir "${working_dir}/sys"
 	mount -t sysfs sysfs "${working_dir}/sys"
 
 -106,11 +109,12 @@ chroot_umount () {
 
 umask 0022
 if [ "$RUN" != "" ]; then
+
 	# run chroot {{{
 	#Sanity check
 	if [ ! -f "${working_dir}/.arch-chroot" ]; then
 		echo "error: '${working_dir}' does not appear to be a Arch chroot"
-		echo '       please build the image using mkarchroot'
+		echo '  please build the image using mkarchroot'
 		exit 1
 	fi
 
 -120,13 +124,21 @@ if [ "$RUN" != "" ]; then
 	chroot "${working_dir}" ${RUN}
 
 	# }}}
-	else
+else
 	# {{{ build chroot
+
 	if [ -e "${working_dir}" -a "${FORCE}" = "n" ]; then
 		echo "error: working dir '${working_dir}' already exists - try using -f"
 		exit 1
 	fi
 
+        if [ "$SARCH" == 'y' ] && [ `arch` == 'x86_64' ]; then
+                sed -i 's|x86_64|i686|g' /etc/pacman.d/mirrorlist
+        elif [ "$SARCH" == 'y' ] && [ `arch` != 'x86_64' ]; then
+                echo 'error: the -s option is only available on 64bit systems'
+                exit 1
+        fi
+
 	mkdir -p "${working_dir}/var/lib/pacman/"
 	mkdir -p "${working_dir}/etc/"
 
 -171,6 +183,10 @@ if [ "$RUN" != "" ]; then
 	if [ ! -e "${working_dir}/.arch-chroot" ]; then
 		date +%s > "${working_dir}/.arch-chroot"
 	fi
+
+        if [ "$SARCH" == "y" ]; then
+                sed -i 's|i686|x86_64|g' /etc/pacman.d/mirrorlist
+        fi
 	# }}}
 fi